@@ -29,7 +29,7 @@
       <?php if ($fields['granted']->raw == 'TRUE'): ?>
         <?php print $fields['still_url']->content; ?>
       <?php else: ?>
-<?php print l(theme('image', array('path' => drupal_get_path('theme', 'sitebuilder_uvt') . '/images/notgranted.png', 'width' => '220px', 'height' => '124px', 'alt' => t("You don't have the right permissions to access this video"))), 'asset/detail/' . $fields['asset_id']->raw, array('html' => TRUE)); ?>
+<?php print l(theme('image', array('path' => drupal_get_path('theme', 'sitebuilder_uvt') . '/images/notgranted.png', 'width' => '220px', 'height' => '124px', 'alt' => t("You don't have the right permissions to access this media"))), 'asset/detail/' . $fields['asset_id']->raw, array('html' => TRUE)); ?>
       <?php endif; ?>
     <?php endif; ?>
   </div>
